@@ -153,15 +153,9 @@ with open(opereto_config_file, 'r') as f:
 OPERETO_HOST = opereto_credentials_json['opereto_host']
 
 
-### TBD - Remove basic auth after migration to OAUTH2.0
 def get_opereto_client():
-    try:
-        OPERETO_TOKEN = opereto_credentials_json['opereto_token']
-        client = OperetoClient(opereto_host=OPERETO_HOST, opereto_token=OPERETO_TOKEN)
-    except KeyError:
-        opereto_user = opereto_credentials_json['opereto_user']
-        opereto_password = opereto_credentials_json['opereto_password']
-        client = OperetoClient(opereto_host=OPERETO_HOST, opereto_user=opereto_user, opereto_password=opereto_password)
+    OPERETO_TOKEN = opereto_credentials_json['opereto_token']
+    client = OperetoClient(opereto_host=OPERETO_HOST, opereto_token=OPERETO_TOKEN)
     return client
 
 
@@ -371,7 +365,6 @@ def local_dev(params):
 
     client = get_opereto_client()
 
-
     def delete_local_dev_config():
         if os.path.exists(json_arguments_file):
             with open(json_arguments_file, 'r') as infile:
